@@ -1,8 +1,8 @@
 import warnings
 from typing import List
 
-from dorothy_sdk.resources import Dataset, Image, QualityAnnotation
-from dorothy_sdk.session import Session
+from dorothy_sdk.resources import Dataset, Image, QualityAnnotation, CrossValidationFolders
+from dorothy_sdk.session import SessionManager
 from dorothy_sdk.utils import url_join
 
 
@@ -10,7 +10,7 @@ class Client:
     _service_host: str = "https://dorothy-image.lps.ufrj.br"
 
     def __init__(self, token=None, **kwargs):
-        self.session = Session(token, **kwargs)
+        self.session = SessionManager(token, **kwargs).build_session()
         if kwargs.get("host"):
             warnings.warn(f"Modifying host from {self._service_host} to {kwargs.get('host')}")
             self._service_host = kwargs.get("host")
@@ -57,3 +57,12 @@ class Client:
             under_penetrated, over_penetrated, costophrenic_cropped, apices_cropped,
             reliable_radiography, minimum_interpretation_quality
         )
+
+    def list_quality_annotations(self):
+        return QualityAnnotation(session=self.session, host=self._service_host, project_id=None).get()
+
+    def list_clusters(self):
+        return CrossValidationFolders(session=self.session, host=self._service_host).get()
+
+    def cluster(self, cluster_id: int):
+        return CrossValidationFolders(session=self.session, host=self._service_host, cluster_id=cluster_id)
