@@ -1,5 +1,5 @@
 from typing import List
-from dorothy_sdk.session import Session
+from requests import Session
 from dorothy_sdk.utils import url_join
 from dorothy_sdk.resources.image import Image
 
